summaryrefslogtreecommitdiffstats
path: root/kopete/plugins/smpppdcs/libsmpppdclient/smpppdready.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/plugins/smpppdcs/libsmpppdclient/smpppdready.cpp')
-rw-r--r--kopete/plugins/smpppdcs/libsmpppdclient/smpppdready.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/kopete/plugins/smpppdcs/libsmpppdclient/smpppdready.cpp b/kopete/plugins/smpppdcs/libsmpppdclient/smpppdready.cpp
index 421914bb..f51aa301 100644
--- a/kopete/plugins/smpppdcs/libsmpppdclient/smpppdready.cpp
+++ b/kopete/plugins/smpppdcs/libsmpppdclient/smpppdready.cpp
@@ -14,7 +14,7 @@
*************************************************************************
*/
-#include <qregexp.h>
+#include <tqregexp.h>
#include <kdebug.h>
#include <kstreamsocket.h>
@@ -48,33 +48,33 @@ void Ready::disconnect(Client * client) {
delete socket(client);
setSocket(client, NULL);
- setServerID(client, QString::null);
- setServerVersion(client, QString::null);
+ setServerID(client, TQString::null);
+ setServerVersion(client, TQString::null);
}
changeState(client, Unsettled::instance());
}
-QStringList Ready::getInterfaceConfigurations(Client * client) {
+TQStringList Ready::getInterfaceConfigurations(Client * client) {
- QStringList ifcfgs;
+ TQStringList ifcfgs;
// we want all ifcfgs
kdDebug(14312) << k_funcinfo << "smpppd req: list-ifcfgs" << endl;
write(client, "list-ifcfgs");
- QStringList stream = read(client);
+ TQStringList stream = read(client);
kdDebug(14312) << k_funcinfo << "smpppd ack: " << stream[0] << endl;
if(stream[0].startsWith("ok")) {
// we have now a QStringList with all ifcfgs
// we extract them and put them in the global ifcfgs-list
// stream[1] tells us how many ifcfgs are coming next
- QRegExp numIfcfgsRex("^BEGIN IFCFGS ([0-9]+).*");
+ TQRegExp numIfcfgsRex("^BEGIN IFCFGS ([0-9]+).*");
if(numIfcfgsRex.exactMatch(stream[1])) {
int count_ifcfgs = numIfcfgsRex.cap(1).toInt();
kdDebug(14312) << k_funcinfo << "ifcfgs: " << count_ifcfgs << endl;
for(int i = 0; i < count_ifcfgs; i++) {
- QRegExp ifcfgRex("^i \"(ifcfg-[a-zA-Z]+[0-9]+)\".*");
+ TQRegExp ifcfgRex("^i \"(ifcfg-[a-zA-Z]+[0-9]+)\".*");
if(ifcfgRex.exactMatch(stream[i+2])) {
ifcfgs.push_back(ifcfgRex.cap(1));
}
@@ -85,14 +85,14 @@ QStringList Ready::getInterfaceConfigurations(Client * client) {
return ifcfgs;
}
-bool Ready::statusInterface(Client * client, const QString& ifcfg) {
+bool Ready::statusInterface(Client * client, const TQString& ifcfg) {
- QString cmd = "list-status " + ifcfg;
+ TQString cmd = "list-status " + ifcfg;
write(client, cmd.latin1());
socket(client)->waitForMore(0);
- QStringList stream = read(client);
+ TQStringList stream = read(client);
if(stream[0].startsWith("ok")) {
if(stream[2].startsWith("status connected")) {
@@ -48,33 +48,33 @@ void Ready::disconnect(Client * client) {
kdDebug(14312) << k_funcinfo << "smpppd ack: " << stream[0] << endl;
if(stream[0].startsWith("ok")) {
- // we have now a QStringList with all ifcfgs
+ // we have now a TQStringList with all ifcfgs
// we extract them and put them in the global ifcfgs-list
// stream[1] tells us how many ifcfgs are coming next